@@ -5,6 +5,8 @@ import torch.nn.functional as F
 
 from axial_positional_embedding import AxialPositionalEmbedding
 from einops import rearrange
+
+from dalle_pytorch.vae import OpenAIDiscreteVAE
 from dalle_pytorch.transformer import Transformer
 
 # helpers
@@ -286,7 +288,7 @@ class DALLE(nn.Module):
         attn_types = None
     ):
         super().__init__()
-        assert isinstance(vae, DiscreteVAE), 'vae must be an instance of DiscreteVAE'
+        assert isinstance(vae, (DiscreteVAE, OpenAIDiscreteVAE)), 'vae must be an instance of DiscreteVAE'
 
         image_size = vae.image_size
         num_image_tokens = vae.num_tokens
